23 experimental studies from Anderson et al. (2010) that meet the best practice criteria
Source:R/datasets.R
Anderson2010.RdThe data set contains correlation coefficients, sample sizes, and labels for 23 experimental studies focusing on the effect of violent video games on aggressive behavior.
Format
A data.frame with 3 columns and 23 observations:
rCorrelation coefficient.
nSample size.
nameStudy label.
References
Anderson CA, Shibuya A, Ihori N, Swing EL, Bushman BJ, Sakamoto A, Rothstein HR, Saleem M (2010). “Violent video game effects on aggression, empathy, and prosocial behavior in Eastern and Western countries: A meta-analytic review.” Psychological Bulletin, 136(2), 151–173. doi:10.1037/a0018251 .