Skip to contents

The data set contains Hedges' g effect sizes, standard errors, sample sizes for experimental and control groups, and various study characteristics including grade level, type of course, duration, learning model, role of ChatGPT, and area of ChatGPT application. The meta-analysis examined the effect of ChatGPT on students' learning performance, learning perception, and higher-order thinking (Wang and Fan 2025) .

Usage

Wang2025

Format

A data.frame with 12 columns and 70 observations:

Learning_effect

Learning-effect outcome category.

Author_year

Author-year study label.

N_EG

Experimental-group sample size.

N_CG

Control-group sample size.

g

Hedges' g effect size.

Grade_level

Grade level.

Type_of_course

Course type.

Duration

Study duration.

Learning_model

Learning model.

Role_of_ChatGPT

Role of ChatGPT in the intervention.

Area_of_ChatGPT_application

Application area.

se

Standard error of g.

References

Wang J, Fan W (2025). “The effect of ChatGPT on students’ learning performance, learning perception, and higher-order thinking: insights from a meta-analysis.” Humanities and Social Sciences Communications, 12(1), 1–21. doi:10.1057/s41599-025-04787-y .