add_waic.brma: Add WAIC to brma Objects

View source: R/loo.R

add_waic.brmaR Documentation

Add WAIC to brma Objects

Description

Compute the Widely Applicable Information Criterion (WAIC) for brma model objects and store the result in the object.

Usage

## S3 method for class 'brma'
add_waic(object, unit = "estimate", ...)

Arguments

object

a brma model object.

unit

output/deletion unit. See add_loo; the same accepted values and multilevel constraint apply.

...

additional arguments passed to waic.

Details

WAIC is an alternative to LOO-CV for estimating out-of-sample predictive accuracy. Like LOO, it evaluates expected predictive performance for new observations.

In most cases, LOO-PSIS (via add_loo) is preferred over WAIC because it provides better estimates and includes diagnostics (Pareto k values) that indicate when the approximation may be unreliable.

Value

The brma object with the WAIC result stored in object[["waic"]][[unit]].

See Also

waic.brma, add_loo, waic


RoBMA documentation built on May 7, 2026, 5:08 p.m.