check_loo.brma: Check LOO Diagnostics for brma Objects

View source: R/loo.R

check_loo.brmaR Documentation

Check LOO Diagnostics for brma Objects

Description

Check Pareto k diagnostics for a brma model object and warn if any values are high.

Usage

## S3 method for class 'brma'
check_loo(object, unit = "estimate", ...)

Arguments

object

a brma model object.

unit

output/deletion unit. See add_loo.

...

currently unused.

Details

LOO must first be computed with object <- add_loo(object, unit = unit). The method warns when any Pareto k diagnostic is greater than 0.7.

Value

NULL (throws warning if diagnostics are unreliable).


RoBMA documentation built on May 7, 2026, 5:08 p.m.