| plot_pet_peese | R Documentation |
plot_pet_peese visualizes posterior
(and prior) PET-PEESE fit of a brma object.
plot_pet_peese(x, ...)
## S3 method for class 'brma'
plot_pet_peese(
x,
show_data = TRUE,
prior = FALSE,
plot_type = "base",
dots_prior = NULL,
...
)
x |
a fitted brma object with a PET or PEESE component. |
... |
list of additional graphical arguments
to be passed to the plotting function. Supported arguments
are |
show_data |
whether the observed effect sizes should be added to
figure. Defaults to |
prior |
whether prior distribution should be added to
figure. Defaults to |
plot_type |
whether to use a base plot |
dots_prior |
list of additional graphical arguments
to be passed to the plotting function of the prior
distribution. Supported arguments are |
The plot shows observed yi values against sei. PET
regression uses \mu + PET \cdot se_i; PEESE regression uses
\mu + PEESE \cdot se_i^2, with the fitted effect direction.
plot_pet_peese returns either NULL invisibly if
plot_type = "base" or a ggplot2 object if
plot_type = "ggplot".
RoBMA()
## Not run:
if (requireNamespace("metadat", quietly = TRUE)) {
data(dat.lehmann2018, package = "metadat")
fit <- bPET(
yi = yi,
vi = vi,
data = dat.lehmann2018,
measure = "SMD",
seed = 1,
silent = TRUE
)
plot_pet_peese(fit)
}
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.