print.summary.brma_samples: Print summary.brma_samples Object

View source: R/brma_samples.R

print.summary.brma_samplesR Documentation

Print summary.brma_samples Object

Description

Prints a summary table of posterior samples using BayesTools::ensemble_estimates_table. Returns the summary table invisibly.

Usage

## S3 method for class 'summary.brma_samples'
print(x, probs = NULL, ...)

Arguments

x

a summary.brma_samples object

probs

quantiles for credible intervals. If NULL, uses the default stored in the object (typically c(.025, .975))

...

additional arguments passed to BayesTools::ensemble_estimates_table

Value

Returns the summary table invisibly.


RoBMA documentation built on May 7, 2026, 5:08 p.m.