| prior_factor | R Documentation |
Create priors on factor contrasts.
prior_factor(
distribution,
parameters,
truncation = list(lower = -Inf, upper = Inf),
prior_weights = 1,
contrast = "meandif"
)
distribution |
character. Prior distribution name. |
parameters |
list. Distribution parameters. |
truncation |
list with |
prior_weights |
numeric prior model weight. |
contrast |
character. Contrast coding used for factor levels. Common
RoBMA model options are |
Mean-difference and orthonormal contrasts require vector or multivariate priors. Treatment/dummy and independent contrasts use univariate simple priors per contrast coefficient.
An object inheriting from prior, prior.factor, and a
contrast-specific marker class.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.