| waic.brma | R Documentation |
Extract the WAIC object from a brma model object.
The WAIC must first be computed using add_waic.
## S3 method for class 'brma'
waic(x, unit = "estimate", ...)
x |
a brma model object. |
unit |
output/deletion unit. See |
... |
additional arguments (currently unused). |
This function extracts the WAIC object that was previously computed and
stored using object <- add_waic(object, unit = unit). If WAIC has not
been computed for the requested unit, an error is thrown.
This is the RoBMA S3 generic and brma method. The method is also
registered for waic, so loo::waic(fit) extracts
the cached WAIC object for brma fits. Use waic
directly for raw log-likelihood arrays or matrices.
In most cases, LOO-PSIS (via loo.brma) is preferred over WAIC
because it provides better estimates and includes diagnostics (Pareto k
values) that indicate when the approximation may be unreliable.
An object of class "waic" as returned by
waic.
add_waic, loo.brma, waic
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.