| Anderson2010 | R Documentation |
The data set contains correlation coefficients, sample sizes, and labels for 23 experimental studies focusing on the effect of violent video games on aggressive behavior.
Anderson2010
A data.frame with 3 columns and 23 observations:
rCorrelation coefficient.
nSample size.
nameStudy label.
https://github.com/Joe-Hilgard/Anderson-meta
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.