Learn R Programming

RoBMA (version 4.0.0)

Anderson2010: 23 experimental studies from anderson2010violent;textualRoBMA that meet the best practice criteria

Description

The data set contains correlation coefficients, sample sizes, and labels for 23 experimental studies focusing on the effect of violent video games on aggressive behavior.

Usage

Anderson2010

Arguments

Format

A data.frame with 3 columns and 23 observations:

r

Correlation coefficient.

n

Sample size.

name

Study label.

References