39 study rows on household chaos and child executive functions from a meta-analysis by Andrews et al. (2021)
Source:R/datasets.R
Andrews2021.RdThe data set contains raw correlation coefficients and
sampling information using metafor-compatible column names
(ri, vi, sei, ni, and slab), together with
study-level moderators from the original data set. Three source rows have
missing effect-size inputs and are omitted automatically by model-fitting
functions that require complete outcomes. The original data set assessed the
effect of household chaos on child executive functions
(Andrews et al. 2021)
and was used as an example in
Bartoš et al. (2025)
.
Format
A data.frame with 15 columns and 39 observations:
study_idSource row identifier.
slabStudy label.
riRaw correlation coefficient.
viSampling variance of the raw correlation coefficient.
seiSampling standard error of the raw correlation coefficient.
niSample size.
yearPublication year.
percent_femalePercentage of female children in the sample.
ageMean age of the children in years.
assessment_interval_monthsTime between household-chaos and executive-function assessments in months.
dissertationWhether the study was a dissertation.
percent_minorityPercentage of minority participants in the sample.
percent_low_parental_educationPercentage of parents with high school, GED, or lower education.
hc_dimensionHousehold-chaos dimension using the source coding.
measureExecutive-function assessment type, direct or informant.
References
Andrews K, Atkinson L, Harris M, Gonzalez A (2021).
“Examining the effects of household chaos on child executive functions: A meta-analysis.”
Psychological Bulletin, 147(1), 16–32.
doi:10.1037/bul0000311
.
Bartoš F, Maier M, Stanley TD, Wagenmakers E (2025).
“Robust Bayesian meta-regression: Model-averaged moderation analysis in the presence of publication bias.”
Psychological Methods.
doi:10.1037/met0000737
.