The data set contains correlation coefficients r,
standard errors se, executive functioning assessment type measure,
and the mean age of the children in each study age. The original data set
assessed the effect of household chaos on child executive functions
andrews2021examiningRoBMA which was used as an
example in bartos2020adjusting;textualRoBMA.
Andrews2021a data.frame.
A data.frame with 4 columns and 36 observations.