Havrankova2025: 1159 effect sizes from a meta-analysis of beauty and...

Havrankova2025R Documentation

1159 effect sizes from a meta-analysis of beauty and professional success by \insertCitehavrankova2025beauty;textualRoBMA

Description

The data set contains effect sizes (percent increase in earnings), standard errors, study identifiers, sample sizes, and the type of customer contact (no, some, or direct). The meta-analysis examined the relationship between perceived beauty and professional success \insertCitehavrankova2025beautyRoBMA.

Usage

Havrankova2025

Format

A data.frame with 5 columns and 1159 observations:

y

Effect size: percent increase in earnings.

se

Standard error of y.

facing_customer

Type of customer contact.

study_id

Study identifier.

N

Sample size.

References

\insertAllCited

RoBMA documentation built on May 7, 2026, 5:08 p.m.