Learn R Programming

RoBMA (version 4.0.0)

Havrankova2025: 1159 effect sizes from a meta-analysis of beauty and professional success by havrankova2025beauty;textualRoBMA

Description

The data set contains effect sizes (percent increase in earnings), standard errors, study identifiers, sample sizes, and the type of customer contact (no, some, or direct). The meta-analysis examined the relationship between perceived beauty and professional success havrankova2025beautyRoBMA.

Usage

Havrankova2025

Arguments

Format

A data.frame with 5 columns and 1159 observations:

y

Effect size: percent increase in earnings.

se

Standard error of y.

facing_customer

Type of customer contact.

study_id

Study identifier.

N

Sample size.

References