The data set contains effect sizes (percent increase in earnings), standard errors, study identifiers, sample sizes, and the type of customer contact (no, some, or direct). The meta-analysis examined the relationship between perceived beauty and professional success havrankova2025beautyRoBMA.
Havrankova2025A data.frame with 5 columns and 1159 observations:
yEffect size: percent increase in earnings.
seStandard error of y.
facing_customerType of customer contact.
study_idStudy identifier.
NSample size.