Learn R Programming

RoBMA (version 3.6.1)

Havrankova2025: 1159 effect sizes from a meta-analysis of beauty and professional success by havrankova2025beauty;textualRoBMA

Description

The data set contains effect sizes (percent increase in earnings), standard errors, study identifiers, sample sizes, and the type of customer contact (no, some, or direct). The meta-analysis examined the relationship between perceived beauty and professional success havrankova2025beautyRoBMA.

Usage

Havrankova2025

Arguments

Value

a data.frame.

Format

A data.frame with 5 columns and 1159 observations.

References