37 studies from a meta-analysis of social comparison as a behavior change technique by Hoppen et al. (2025)
Source:R/datasets.R
Hoppen2025.RdThe data set contains Cohen's d effect sizes, variances, and study characteristics including outcome type, feedback level, social comparison type, number of sessions, sample type, sample size, and country. The meta-analysis examined social comparison as a behavior change technique across the behavioral sciences (Hoppen et al. 2025) .
Format
A data.frame with 9 columns and 37 observations:
dCohen's d effect size.
vSampling variance of d.
outcomeOutcome type.
feedback_levelFeedback level.
social_comparison_typeSocial-comparison type.
sessionsNumber of sessions.
sample_typeSample type.
sample_sizeSample size.
countryCountry.
References
Hoppen TH, Cuno RM, Nelson J, Lemmel F, Schlechter P, Morina N (2025). “Meta-analysis of randomized controlled trials examining social comparison as a behaviour change technique across the behavioural sciences.” Nature Human Behaviour, 9(8), 1595–1612. doi:10.1038/s41562-025-02209-2 .