Learn R Programming

RoBMA (version 4.0.0)

Hoppen2025: 37 studies from a meta-analysis of social comparison as a behavior change technique by hoppen2025meta;textualRoBMA

Description

The data set contains Cohen's d effect sizes, variances, and study characteristics including outcome type, feedback level, social comparison type, number of sessions, sample type, sample size, and country. The meta-analysis examined social comparison as a behavior change technique across the behavioral sciences hoppen2025metaRoBMA.

Usage

Hoppen2025

Arguments

Format

A data.frame with 9 columns and 37 observations:

d

Cohen's d effect size.

v

Sampling variance of d.

outcome

Outcome type.

feedback_level

Feedback level.

social_comparison_type

Social-comparison type.

sessions

Number of sessions.

sample_type

Sample type.

sample_size

Sample size.

country

Country.

References