The data set contains Cohen's d effect sizes, variances, and study characteristics including outcome type, feedback level, social comparison type, number of sessions, sample type, sample size, and country. The meta-analysis examined social comparison as a behavior change technique across the behavioral sciences hoppen2025metaRoBMA.
Hoppen2025A data.frame with 9 columns and 37 observations:
dCohen's d effect size.
vSampling variance of d.
outcomeOutcome type.
feedback_levelFeedback level.
social_comparison_typeSocial-comparison type.
sessionsNumber of sessions.
sample_typeSample type.
sample_sizeSample size.
countryCountry.