Learn R Programming

RoBMA (version 3.6.1)

Hoppen2025: 37 studies from a meta-analysis of social comparison as a behavior change technique by hoppen2025meta;textualRoBMA

Description

The data set contains Cohen's d effect sizes, variances, and study characteristics including outcome type, feedback level, social comparison type, number of sessions, sample type, sample size, and country. The meta-analysis examined social comparison as a behavior change technique across the behavioral sciences hoppen2025metaRoBMA.

Usage

Hoppen2025

Arguments

Value

a data.frame.

Format

A data.frame with 9 columns and 37 observations.

References