Learn R Programming

RoBMA (version 3.6.1)

Johnides2025: 412 effect sizes from a meta-analysis of secondary benefits of family-based treatments by johnides2025secondary;textualRoBMA

Description

The data set contains Cohen's d effect sizes, standard errors, and study labels from a meta-analysis investigating the extent to which family-based treatments for children with mental health, physical health, and developmental disorders provide secondary benefits to the children's siblings and caregivers johnides2025secondaryRoBMA.

Usage

Johnides2025

Arguments

Value

a data.frame.

Format

A data.frame with 3 columns and 412 observations.

References