The data set contains partial correlation coefficients, standard errors, study labels, sample sizes, type of the educational outcome, intensity of the employment, gender of the student population, study location, study design, whether the study controlled for endogeneity, and whether the study controlled for motivation. The original data set including additional variables and the publication are available from the project page. (Note that some standard errors and employment intensities are missing.)
Kroupova2021A data.frame with 11 columns and 881 observations:
rPartial correlation coefficient.
seStandard error of r.
studyStudy label.
sample_sizeSample size.
education_outcomeType of educational outcome.
employment_intensityEmployment intensity.
students_genderGender composition of the student sample.
locationStudy location.
designStudy design.
endogenity_controlWhether endogeneity was controlled.
motivation_controlWhether motivation was controlled.