Inspect or change package-level defaults used by RoBMA.
Value
RoBMA.options() invisibly returns a named list with all current
options after applying any changes. RoBMA.get_option() returns the current
value of the requested option.
Details
The available options are:
max_coresnumber of cores to use for parallel computing (default is one fewer than detected logical cores, with a minimum/fallback of 1)
check_scalingwhether to check scaling of predictors (default
TRUE)silentwhether to suppress output (default
FALSE)autocompute.loowhether to automatically compute LOO (default
FALSE)autocompute.waicwhether to automatically compute WAIC (default
FALSE)autocompute.marglikwhether to automatically compute marginal likelihood (default
FALSE)cluster_likelihood.n_gammanumber of Gauss-Hermite nodes used for cluster-unit log-likelihoods (default
15)default_UISD.effectdefault scaling of the unit information standard deviation for the effect size parameter (default
0.5)default_UISD.heterogeneitydefault scaling of the unit information standard deviation for the heterogeneity parameter (default
0.25)default_UISD.modsdefault scaling of the unit information standard deviation for the moderators (default
0.25)default_UISD.scaledefault scaling of the unit information standard deviation for the scale parameter (default
0.5)default_informed_priors.modsdefault scaling of informed priors for moderators (default
0.5)default_informed_priors.scaledefault scaling of informed priors for the scale parameter (default
0.5)default_bias_weightfunction.alphadefault alpha for the weightfunction (default
1)default_bias_PET.scaledefault scale for the PET (default
1)default_bias_PEESE.scaledefault scale for the PEESE (default
5)
Boolean options require scalar TRUE or FALSE values.
max_cores must be integer-like and at least 1;
cluster_likelihood.n_gamma must be integer-like and at least 3.
Scale and alpha defaults must be finite positive numbers.