70 effect sizes from a meta-analysis of ChatGPT's impact on student learning by Wang and Fan (2025)
Source:R/datasets.R
Wang2025.RdThe data set contains Hedges' g effect sizes, standard errors, sample sizes for experimental and control groups, and various study characteristics including grade level, type of course, duration, learning model, role of ChatGPT, and area of ChatGPT application. The meta-analysis examined the effect of ChatGPT on students' learning performance, learning perception, and higher-order thinking (Wang and Fan 2025) .
Format
A data.frame with 12 columns and 70 observations:
Learning_effectLearning-effect outcome category.
Author_yearAuthor-year study label.
N_EGExperimental-group sample size.
N_CGControl-group sample size.
gHedges' g effect size.
Grade_levelGrade level.
Type_of_courseCourse type.
DurationStudy duration.
Learning_modelLearning model.
Role_of_ChatGPTRole of ChatGPT in the intervention.
Area_of_ChatGPT_applicationApplication area.
seStandard error of g.
References
Wang J, Fan W (2025). “The effect of ChatGPT on students’ learning performance, learning perception, and higher-order thinking: insights from a meta-analysis.” Humanities and Social Sciences Communications, 12(1), 1–21. doi:10.1057/s41599-025-04787-y .