Learn R Programming

RoBMA (version 4.0.0)

Wang2025: 70 effect sizes from a meta-analysis of ChatGPT's impact on student learning by wang2025effect;textualRoBMA

Description

The data set contains Hedges' g effect sizes, standard errors, sample sizes for experimental and control groups, and various study characteristics including grade level, type of course, duration, learning model, role of ChatGPT, and area of ChatGPT application. The meta-analysis examined the effect of ChatGPT on students' learning performance, learning perception, and higher-order thinking wang2025effectRoBMA.

Usage

Wang2025

Arguments

Format

A data.frame with 12 columns and 70 observations:

Learning_effect

Learning-effect outcome category.

Author_year

Author-year study label.

N_EG

Experimental-group sample size.

N_CG

Control-group sample size.

g

Hedges' g effect size.

Grade_level

Grade level.

Type_of_course

Course type.

Duration

Study duration.

Learning_model

Learning model.

Role_of_ChatGPT

Role of ChatGPT in the intervention.

Area_of_ChatGPT_application

Application area.

se

Standard error of g.

References