The data set contains Hedges' g effect sizes, standard errors, sample sizes for experimental and control groups, and various study characteristics including grade level, type of course, duration, learning model, role of ChatGPT, and area of ChatGPT application. The meta-analysis examined the effect of ChatGPT on students' learning performance, learning perception, and higher-order thinking wang2025effectRoBMA.
Wang2025A data.frame with 12 columns and 70 observations:
Learning_effectLearning-effect outcome category.
Author_yearAuthor-year study label.
N_EGExperimental-group sample size.
N_CGControl-group sample size.
gHedges' g effect size.
Grade_levelGrade level.
Type_of_courseCourse type.
DurationStudy duration.
Learning_modelLearning model.
Role_of_ChatGPTRole of ChatGPT in the intervention.
Area_of_ChatGPT_applicationApplication area.
seStandard error of g.