Learn R Programming

RoBMA (version 3.6.1)

Wang2025: 70 effect sizes from a meta-analysis of ChatGPT's impact on student learning by wang2025effect;textualRoBMA

Description

The data set contains Hedges' g effect sizes, standard errors, sample sizes for experimental and control groups, and various study characteristics including grade level, type of course, duration, learning model, role of ChatGPT, and area of ChatGPT application. The meta-analysis examined the effect of ChatGPT on students' learning performance, learning perception, and higher-order thinking wang2025effectRoBMA.

Usage

Wang2025

Arguments

Value

a data.frame.

Format

A data.frame with 12 columns and 70 observations.

References