The data set contains correlation coefficients between the manipulation and outcome variable (r_xy), sample sizes (N), and various study characteristics including publication status, country (USA vs. other), number of few and many examples requested, whether the trial targeted episodic memory, paradigm type (standard vs. other), dataset type (proximal vs. distal), and mediation variables (r_xm, r_my). The meta-analysis examined whether subjective ease mediates the ease-of-retrieval effect, where participants list either few or many examples and then make judgments weingarten2018doesRoBMA.
Weingarten2018A data.frame with 12 columns and 582 observations:
r_xyCorrelation between manipulation and outcome.
NSample size.
paper_idPaper identifier.
publishedPublication-status indicator.
USAWhether the study was conducted in the USA.
number_of_fewNumber of examples in the few-examples condition.
number_of_manyNumber of examples in the many-examples condition.
episodic_memoryWhether the trial targeted episodic memory.
standard_paradigmWhether the standard paradigm was used.
proximal_datasetWhether the data set was proximal.
r_xmCorrelation between manipulation and mediator.
r_myCorrelation between mediator and outcome.