Compute the Widely Applicable Information Criterion (WAIC) for brma model objects and store the result in the object.
Details
WAIC is an alternative to LOO-CV for estimating out-of-sample predictive accuracy. Like LOO, it evaluates expected predictive performance for new observations.
In most cases, LOO-PSIS (via add_loo) is preferred over WAIC
because it provides better estimates and includes diagnostics (Pareto k
values) that indicate when the approximation may be unreliable.