| add_waic.brma | R Documentation |
Compute the Widely Applicable Information Criterion (WAIC) for brma model objects and store the result in the object.
## S3 method for class 'brma'
add_waic(object, unit = "estimate", ...)
object |
a brma model object. |
unit |
output/deletion unit. See |
... |
additional arguments passed to |
WAIC is an alternative to LOO-CV for estimating out-of-sample predictive accuracy. Like LOO, it evaluates expected predictive performance for new observations.
In most cases, LOO-PSIS (via add_loo) is preferred over WAIC
because it provides better estimates and includes diagnostics (Pareto k
values) that indicate when the approximation may be unreliable.
The brma object with the WAIC result stored in
object[["waic"]][[unit]].
waic.brma, add_loo, waic
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.