Learn R Programming

RoBMA (version 4.0.0)

add_waic.brma: Add WAIC to brma Objects

Description

Compute the Widely Applicable Information Criterion (WAIC) for brma model objects and store the result in the object.

Usage

# S3 method for brma
add_waic(object, unit = "estimate", ...)

Value

The brma object with the WAIC result stored in object[["waic"]][[unit]].

Arguments

object

a brma model object.

unit

output/deletion unit. See add_loo; the same accepted values and multilevel constraint apply.

...

additional arguments passed to waic.

Details

WAIC is an alternative to LOO-CV for estimating out-of-sample predictive accuracy. Like LOO, it evaluates expected predictive performance for new observations.

In most cases, LOO-PSIS (via add_loo) is preferred over WAIC because it provides better estimates and includes diagnostics (Pareto k values) that indicate when the approximation may be unreliable.

See Also

waic.brma, add_loo, waic