Learn R Programming

RoBMA (version 4.0.0)

bridge_sampler.brma: Bridge Sampling for brma Objects

Description

Extract the marginal likelihood bridge sampling object from a brma model. The marginal likelihood must first be computed using add_marglik.

Usage

# S3 method for brma
bridge_sampler(samples, ...)

Value

An object of class "bridge" as returned by bridge_sampler.

Arguments

samples

a brma model object.

...

additional arguments (currently not used).

Details

This function extracts the bridge sampling object that was previously computed and stored using add_marglik. If the marginal likelihood has not been computed, an error is thrown. Product-space model-averaging objects (BMA.norm, BMA.glmm, and RoBMA) do not expose bridge-sampling marginal likelihoods.

The returned object can be used for Bayesian model comparison via bf and post_prob.

See Also

add_marglik, bridge_sampler, logml.brma, bf.brma, post_prob.brma

Examples

Run this code
if (FALSE) {
if (requireNamespace("metadat", quietly = TRUE)) {
  data(dat.lehmann2018, package = "metadat")
  fit <- brma(yi = yi, vi = vi, data = dat.lehmann2018, measure = "SMD")

  fit <- add_marglik(fit)

  bridge <- bridge_sampler(fit)
  print(bridge)
}
}

Run the code above in your browser using DataLab