| brma.glmm | R Documentation |
Function for fitting random-effects, meta-regression, multilevel, and location-scale meta-analytic models directly to either binary or count data.
brma.glmm(
ai,
bi,
ci,
di,
n1i,
n2i,
x1i,
x2i,
t1i,
t2i,
weights,
mods,
scale,
cluster,
data,
slab,
subset,
measure = "OR",
prior_effect,
prior_heterogeneity,
prior_mods,
prior_scale,
prior_heterogeneity_allocation,
prior_baserate,
prior_lograte,
standardize_continuous_predictors = TRUE,
set_contrast_factor_predictors = "treatment",
prior_unit_information_sd,
rescale_priors = 1,
prior_informed_field,
prior_informed_subfield,
sample = 5000,
burnin = 2000,
adapt = 500,
chains = 3,
thin = 1,
parallel = FALSE,
autofit = FALSE,
autofit_control = set_autofit_control(),
convergence_checks = set_convergence_checks(),
seed = NULL,
silent,
...
)
ai |
a vector of the number of events in the treatment or experimental group for binomial GLMM models. |
bi |
a vector of the number of non-events in the treatment or experimental group for binomial GLMM models. |
ci |
a vector of the number of events in the control group for binomial GLMM models. |
di |
a vector of the number of non-events in the control group for binomial GLMM models. |
n1i |
a vector of the sample size in the treatment or experimental
group. If omitted for binomial GLMMs, it is computed as |
n2i |
a vector of the sample size in the control group. If omitted for
binomial GLMMs, it is computed as |
x1i |
a vector of the number of events in the treatment/experimental group (for Poisson data). |
x2i |
a vector of the number of events in the control group (for Poisson data). |
t1i |
a vector of the person-time in the treatment/experimental group. |
t2i |
a vector of the person-time in the control group. |
weights |
an optional vector of positive likelihood weights. For normal/effect-size models, each weight powers the estimate likelihood. For constructors with GLMM raw-count input, each weight powers the paired two-arm likelihood for one study. |
mods |
an optional matrix, data.frame, or formula specifying
location moderators (meta-regressors). Formula input is evaluated in |
scale |
an optional matrix, data.frame, or formula specifying
scale predictors for location-scale models. Formula input is evaluated in
|
cluster |
an optional vector of cluster identifiers for multilevel meta-analysis. |
data |
an optional data frame containing the variables. |
slab |
an optional vector of study labels. |
subset |
an optional logical or numeric vector specifying a subset of data to be used. |
measure |
a character string specifying the effect size measure.
Normal/effect-size constructors require an explicit value and support
|
prior_effect |
prior distribution for the effect size ( |
prior_heterogeneity |
prior distribution for the heterogeneity ( |
prior_mods |
prior distribution for the moderators ( |
prior_scale |
prior distribution for the scale ( |
prior_heterogeneity_allocation |
prior distribution for the fraction of
heterogeneity allocated to the cluster-level component in multilevel models
( |
prior_baserate |
prior distribution for the estimate-specific midpoint
base-rate probability in binomial GLMM models. If omitted or |
prior_lograte |
prior distribution for the estimate-specific midpoint
log-rate in Poisson GLMM models. If omitted or |
standardize_continuous_predictors |
logical. Whether to standardize continuous predictors.
Defaults to |
set_contrast_factor_predictors |
character. How to set contrast for factor predictors.
Defaults are constructor-specific and shown in each function usage; single-model
constructors use |
prior_unit_information_sd |
numeric. The unit information standard deviation ( |
rescale_priors |
numeric. A scaling factor for supported prior distributions.
Point and none priors are unchanged. For constructors with publication-bias
prior distributions, |
prior_informed_field |
character. The field of the informed prior distributions.
Omit to use the standard default prior specification; explicit |
prior_informed_subfield |
character. The subfield of the informed prior distributions.
Omit to use the field-specific default, such as |
sample |
numeric. Number of MCMC samples to save. Defaults to |
burnin |
numeric. Number of burn-in iterations. Defaults to |
adapt |
numeric. Number of adaptation iterations. Defaults to |
chains |
numeric. Number of MCMC chains. Defaults to |
thin |
numeric. Thinning interval. Defaults to |
parallel |
logical. Whether to run MCMC chains in parallel. Defaults to |
autofit |
logical. Whether to automatically extend the MCMC chains if convergence is not met.
Defaults to |
autofit_control |
list of autofit control settings. See |
convergence_checks |
list of convergence check settings. See |
seed |
numeric. Random seed for reproducibility. Defaults to |
silent |
logical. Whether to suppress output. Constructors with no
explicit default use |
... |
additional advanced arguments. Fitting functions reject unused
arguments; currently recognized internal arguments include |
Model for odds ratios (measure = "OR") corresponds to Model 4 described in
\insertCitejackson2018comparison;textualRoBMA.
logit(pi[i]) is the study-specific midpoint of the two arm logits.
prior_baserate defines the estimate-specific prior distribution on pi[i].
Model for incidence rate ratios (measure = "IRR") corresponds to
\insertCitebagos2009mixed;textualRoBMA.
phi[i] is the study-specific midpoint of the two arm log incidence rates.
prior_lograte defines the estimate-specific prior distribution on phi[i].
If unspecified, a unit-information prior is based on the data and used
independently for each estimate.
When weights are supplied, they are treated as likelihood weights on the
paired two-arm study contribution.
A fitted object of class c("brma.glmm", "brma"). The object
contains checked data, checked priors, the JAGS fit, cached summary,
and cached coefficients. If the corresponding package options are enabled,
it can also contain cached LOO, WAIC, or marginal likelihood results.
brma(), BMA.glmm(), summary.brma(), predict.brma()
## Not run:
if (requireNamespace("metadat", quietly = TRUE)) {
data(dat.bcg, package = "metadat")
fit <- brma.glmm(
ai = tpos,
bi = tneg,
ci = cpos,
di = cneg,
mods = ~ alloc,
data = dat.bcg,
measure = "OR",
seed = 1,
silent = TRUE
)
summary(fit)
}
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.