Learn R Programming

RoBMA (version 4.0.0)

cooks.distance.brma: Cook's Distance for brma Objects

Description

Computes Cook's distance for a fitted brma object. Cook's distance measures the aggregate influence of each observation on the model coefficients.

Usage

# S3 method for brma
cooks.distance(model, ...)

Value

A numeric vector of Cook's distance values, one for each observation.

Arguments

model

a fitted brma object.

...

additional arguments (currently ignored).

Details

Cook's distance is computed as a PSIS leave-one-out deletion diagnostic. For each observation \(i\), normalized PSIS weights estimate the fitted values under the leave-one-out posterior. The distance is the posterior Mahalanobis distance between the full-data and leave-one-out fitted-value vectors: $$D_i = \frac{\Delta_i' V_\mu^+ \Delta_i}{P}$$

where \(\Delta_i = \hat{\mu} - \hat{\mu}_{(-i)}\), \(V_\mu^+\) is the generalized inverse of the full-posterior fitted-value covariance, and \(P\) is the rank of the fixed-effect model matrix.

See Also

influence.brma, dffits.brma, hatvalues.brma

Examples

Run this code
if (FALSE) {
if (requireNamespace("metadat", quietly = TRUE)) {
  data(dat.lehmann2018, package = "metadat")
  fit <- bPET(yi = yi, vi = vi, data = dat.lehmann2018, measure = "SMD")
  fit <- add_loo(fit)

  cooks.distance(fit)
}
}

Run the code above in your browser using DataLab