Shared data-input arguments used by the RoBMA fitting functions.
Normal models use approximate effect-size estimates supplied through
yi with either vi or sei. GLMM models use the raw two-arm count
arguments for binomial (measure = "OR") or Poisson (measure = "IRR")
outcomes.
Arguments
- yi
a vector of effect sizes, or a formula with the effect size on the left-hand side and location moderators on the right-hand side (for example
yi ~ x1 + x2). If a formula is supplied,modsmust not be specified.- vi
a vector of sampling variances. Either
viorseimust be supplied for normal models.- sei
a vector of standard errors. Either
viorseimust be supplied for normal models.- weights
an optional vector of positive likelihood weights. For normal/effect-size models, each weight powers the estimate likelihood. For constructors with GLMM raw-count input, each weight powers the paired two-arm likelihood for one study.
- ni
an optional vector of sample sizes. Used for
measure = "GEN"or when estimating"UISD").- mods
an optional matrix, data.frame, or formula specifying location moderators (meta-regressors). Formula input is evaluated in
data.- scale
an optional matrix, data.frame, or formula specifying scale predictors for location-scale models. Formula input is evaluated in
data.- cluster
an optional vector of cluster identifiers for multilevel meta-analysis.
- data
an optional data frame containing the variables.
- slab
an optional vector of study labels.
- subset
an optional logical or numeric vector specifying a subset of data to be used.
- measure
a character string specifying the effect size measure. Normal/effect-size constructors require an explicit value and support
"SMD","ZCOR","RR","OR","HR","RD","IRR", and"GEN". Use"GEN"only for general effect sizes without a known unit information standard deviation. GLMM raw-count constructors support only"OR"and"IRR"and default to"OR".- effect_direction
direction used by publication-bias adjustments.
"positive"assumes statistically significant positive estimates are more likely to be selected;"negative"mirrors the selection direction;"detect"infers the direction from the fitted data.- ai
a vector of the number of events in the treatment or experimental group for binomial GLMM models.
- bi
a vector of the number of non-events in the treatment or experimental group for binomial GLMM models.
- ci
a vector of the number of events in the control group for binomial GLMM models.
- di
a vector of the number of non-events in the control group for binomial GLMM models.
- n1i
a vector of the sample size in the treatment or experimental group. If omitted for binomial GLMMs, it is computed as
ai + bi.- n2i
a vector of the sample size in the control group. If omitted for binomial GLMMs, it is computed as
ci + di.- x1i
a vector of the number of events in the treatment/experimental group (for Poisson data).
- x2i
a vector of the number of events in the control group (for Poisson data).
- t1i
a vector of the person-time in the treatment/experimental group.
- t2i
a vector of the person-time in the control group.