Learn R Programming

RoBMA (version 4.0.0)

influence.brma: Measure Influence for brma Objects

Description

Computes DFFITS, Cook's distance, COVRATIO, and other influence diagnostics for a fitted brma object.

Usage

# S3 method for brma
influence(model, ...)

Value

An object of class "infl.brma", which corresponds to the structure of metafor::influence objects. It is a list containing:

inf

A data frame with columns: rstudent, dffits, cook.d, cov.r, tau.del, and hat, where available. The tau.del column is the PSIS leave-one-out posterior mean of the aggregate heterogeneity. For scale models, aggregation is over the remaining scale-model rows after each deletion.

dfbs

A data frame with DFBETAS values for the model coefficients.

Undefined determinant- or variance-standardized diagnostics are reported as NaN and printed with an explanatory note.

Arguments

model

a fitted brma object.

...

additional arguments (currently ignored).

See Also

dffits.brma, cooks.distance.brma, covratio.brma, dfbetas.brma, hatvalues.brma

Examples

Run this code
if (FALSE) {
if (requireNamespace("metadat", quietly = TRUE)) {
  data(dat.lehmann2018, package = "metadat")
  fit <- brma(
    yi      = yi,
    vi      = vi,
    data    = dat.lehmann2018,
    measure = "SMD",
    seed    = 1,
    silent  = TRUE
  )
  fit <- add_loo(fit)

  inf <- influence(fit)
  print(inf)
}
}

Run the code above in your browser using DataLab