Adds lines to a plot of a fitted zcurve_RoBMA object. This function is typically used to overlay additional information or model fits on an existing plot.
# S3 method for zcurve_RoBMA
lines(
x,
conditional = FALSE,
plot_type = "base",
probs = c(0.025, 0.975),
max_samples = 500,
extrapolate = FALSE,
plot_CI = TRUE,
from = -6,
to = 6,
by = 0.05,
length.out = NULL,
col = if (extrapolate) "blue" else "black",
...
)A RoBMA object
whether conditional estimates should be
plotted. Defaults to FALSE which plots the model-averaged
estimates. Note that both "weightfunction" and
"PET-PEESE" are always ignoring the other type of
publication bias adjustment.
whether to use a base plot "base"
or ggplot2 "ggplot" for plotting. Defaults to
"base".
quantiles of the posterior samples to be displayed.
Defaults to c(.025, .975)
Maximum number of samples from the posterior distribution that will be used for estimating z-curve estimates.
Logical indicating whether to extrapolate values beyond the observed data range.
Should credible intervals be included in the plot? Defaults to TRUE.
Lower bound of the z-value range for plotting. Defaults to -6.
Upper bound of the z-value range for plotting. Defaults to 6.
Numeric value specifying the increment for the sequence.
Optional integer specifying the desired length of the output sequence.
Color of the plotted line.
Additional graphical parameters for the line and CI ribbon.
For base R lines: lwd, col, lty.
For base R ribbon: alpha (alpha transparency for the ribbon).
For ggplot2 lines: linewidth, color, linetype.
For ggplot2 ribbon: alpha.
as_zcurve(), plot.zcurve_RoBMA(), hist.zcurve_RoBMA()