View source: R/marginal_means.R
| plot.marginal_means.brma | R Documentation |
Plots estimated marginal means stored in a
marginal_means.brma object using BayesTools::plot_marginal().
## S3 method for class 'marginal_means.brma'
plot(
x,
parameter,
type = NULL,
prior = FALSE,
plot_type = "base",
dots_prior = NULL,
output_measure = NULL,
transform = NULL,
...
)
x |
a |
parameter |
moderator term to plot. Use the original term name, for
example |
type |
for RoBMA product-space objects, whether to plot model-averaged
( |
prior |
whether the marginal prior distribution should be added to the
plot. Defaults to |
plot_type |
whether to use base R graphics ( |
dots_prior |
list of additional graphical arguments passed to the prior plotting function. |
output_measure |
effect-size measure for location/effect predictions.
Defaults to the fitted measure. Supported conversions are among |
transform |
optional display transformation. Currently |
... |
additional graphical arguments passed to
|
NULL invisibly if plot_type = "base" or a ggplot object
if plot_type = "ggplot".
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.