| pooled_effect.brma | R Documentation |
Computes the pooled (aggregated) effect size estimate from a fitted brma object by averaging across the moderator model matrix.
## S3 method for class 'brma'
pooled_effect(
object,
bias_adjusted = TRUE,
output_measure = NULL,
transform = NULL,
probs = c(0.025, 0.975),
conditional = FALSE,
...
)
object |
a fitted brma object |
bias_adjusted |
whether to adjust for publication bias. Defaults to
|
output_measure |
effect-size measure for location/effect predictions.
Defaults to the fitted measure. Supported conversions are among |
transform |
optional display transformation. Currently |
probs |
quantiles of the posterior distribution to be displayed.
Defaults to |
conditional |
whether to return the pooled effect conditional on the
effect component for RoBMA product-space objects. Defaults to |
... |
additional arguments passed to |
This function is a convenience wrapper around predict.brma(...,
type = "terms", newdata = TRUE, bias_adjusted = TRUE, quiet = TRUE).
For meta-regression models, the pooled effect averages the effect size estimate across moderator levels proportionately to the levels observed in the data. This provides an estimate representative of the sample of studies.
For models without moderators, this returns the single mu parameter.
A brma_samples object containing posterior samples. When printed,
displays a summary table. Use summary() to obtain the summary table directly.
The samples can be converted to posterior draws formats using as_draws().
predict.brma(), pooled_heterogeneity(), blup()
## Not run:
if (requireNamespace("metadat", quietly = TRUE)) {
data(dat.lehmann2018, package = "metadat")
fit <- brma(
yi = yi,
vi = vi,
data = dat.lehmann2018,
measure = "SMD",
seed = 1,
silent = TRUE
)
pooled_effect(fit)
}
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.