Learn R Programming

RoBMA (version 4.0.0)

print.summary.brma_samples: Print summary.brma_samples Object

Description

Prints a summary table of posterior samples using BayesTools::ensemble_estimates_table. Returns the summary table invisibly.

Usage

# S3 method for summary.brma_samples
print(x, probs = NULL, ...)

Value

Returns the summary table invisibly.

Arguments

x

a summary.brma_samples object

probs

quantiles for credible intervals. If NULL, uses the default stored in the object (typically c(.025, .975))

...

additional arguments passed to BayesTools::ensemble_estimates_table