Create priors on factor contrasts.
prior_factor(
distribution,
parameters,
truncation = list(lower = -Inf, upper = Inf),
prior_weights = 1,
contrast = "meandif"
)An object inheriting from prior, prior.factor, and a
contrast-specific marker class.
character. Prior distribution name.
list. Distribution parameters.
list with lower and upper truncation bounds.
numeric prior model weight.
character. Contrast coding used for factor levels. Common
RoBMA model options are "treatment", "meandif", and
"orthonormal"; the standalone helper also accepts BayesTools contrast
aliases such as "independent".
Mean-difference and orthonormal contrasts require vector or multivariate priors. Treatment/dummy and independent contrasts use univariate simple priors per contrast coefficient.