| prior_specification | R Documentation |
Prior distributions can be supplied for all model parameters. When omitted, the fitting functions construct defaults from the effect-size measure, sample sizes, or informed-prior settings when available.
This typically includes the pooled effect \mu and between-study heterogeneity
\tau. In the case of meta-regression, the pooled effect \mu corresponds to
the intercept, and additional prior distributions for the regression coefficients
are required. In the case of a location-scale model, the between-study heterogeneity
corresponds to the intercept of the scale regression, and additional prior
distributions for the scale regression coefficients are required.
prior_effect |
prior distribution for the effect size ( |
prior_heterogeneity |
prior distribution for the heterogeneity ( |
prior_mods |
prior distribution for the moderators ( |
prior_scale |
prior distribution for the scale ( |
prior_heterogeneity_allocation |
prior distribution for the fraction of
heterogeneity allocated to the cluster-level component in multilevel models
( |
prior_baserate |
prior distribution for the estimate-specific midpoint
base-rate probability in binomial GLMM models. If omitted or |
prior_lograte |
prior distribution for the estimate-specific midpoint
log-rate in Poisson GLMM models. If omitted or |
prior_unit_information_sd |
numeric. The unit information standard deviation ( |
rescale_priors |
numeric. A scaling factor for supported prior distributions.
Point and none priors are unchanged. For constructors with publication-bias
prior distributions, |
standardize_continuous_predictors |
logical. Whether to standardize continuous predictors.
Defaults to |
set_contrast_factor_predictors |
character. How to set contrast for factor predictors.
Defaults are constructor-specific and shown in each function usage; single-model
constructors use |
prior_informed_field |
character. The field of the informed prior distributions.
Omit to use the standard default prior specification; explicit |
prior_informed_subfield |
character. The subfield of the informed prior distributions.
Omit to use the field-specific default, such as |
There are several ways to specify the prior distributions:
via a standardized effect size measure with known unit information standard deviation,
by estimating unit information standard deviation using sample sizes ni,
by manually setting prior_unit_information_sd,
by specifying informed empirical prior distributions via prior_informed_field
and prior_informed_subfield,
or via fully custom specification using the prior_effect, prior_heterogeneity,
prior_mods, prior_scale, and prior_heterogeneity_allocation arguments.
In all cases, the prior behavior can be further modified by the rescale_priors,
standardize_continuous_predictors, and set_contrast_factor_predictors arguments.
unit information standard deviation
This is the easiest way to specify prior distributions. The width of prior
distributions is based on a fraction of the known unit information standard deviation (UISD)
\insertCiterover2021weaklyRoBMA. The default prior distributions for the parameters
are set as follows:
| effect size: | Normal(0, \frac{1}{2} UISD) |
| heterogeneity: | Normal+(0, \frac{1}{4} UISD) |
| effect moderation: | Normal(0, \frac{1}{4} UISD) |
| heterogeneity moderation: | Normal(0, \frac{1}{2})
|
The heterogeneity moderation parameters are multiplicative, as such they are independent of UISD.
The default fraction of the UISD can be changed via RoBMA.options() using one of
the following arguments: "default_UISD.effect", "default_UISD.heterogeneity",
"default_UISD.mods", "default_UISD.scale".
The known UISD for standardized effect size measures (measure) are set as follows:
"SMD": | \sqrt{2} |
"ZCOR": | 1 |
"RR": | \sqrt{4} |
"OR": | \sqrt{4} |
"HR": | \sqrt{4} |
"IRR": | \sqrt{4}
|
See Chapter 2.4 in \insertCitespiegelhalter2004bayesian;textualRoBMA and Chapter 1 in \insertCitegrieve2022hybrid;textualRoBMA.
When effect sizes are on a non-standardized scale (measure = "GEN") or use a
standardized effect size without known UISD, the UISD can be estimated from
sample sizes (ni) and standard errors (sei) following Equation 6 in
\insertCiterover2021weakly;textualRoBMA. The estimated UISD is then used to
scale the default prior distributions as described in section (1).
Note that the known UISD for standardized effect size measures (section (1)) is
used if available, even when ni is provided.
Alternatively, the UISD can be specified directly via the prior_unit_information_sd
argument. This is useful when the appropriate scale for prior distributions is known
a priori or when multiple analyses are to be performed on subsets of the same data
(re-estimating UISD on different subsets of the data can lead to slightly different
prior distributions for different subsets; see estimate_unit_information_sd()).
The specified prior_unit_information_sd is then used to scale the default prior
distributions as described in section (1).
Note that the manually specified prior_unit_information_sd takes precedence over
the estimated UISD from ni (section (2)) and the known UISD from measure
(section (1)). It cannot be combined with prior_informed_field.
Informed prior distributions can be specified via the prior_informed_field and
prior_informed_subfield arguments. Currently, only prior_informed_field = "medicine"
with subfields defined in BayesTools::prior_informed_medicine_names is supported,
which uses empirically derived prior distributions from medical meta-analyses as described in
\insertCitebartos2021bayesian;textualRoBMA and
\insertCitebartos2023empirical;textualRoBMA.
When prior_informed_field = "medicine", the default prior_informed_subfield is
"Cochrane" (i.e., using the whole CDSR database as a reference). The informed
prior distributions are available for the following effect size measures:
"SMD": | standardized mean difference |
"OR": | log odds ratio |
"RR": | log risk ratio |
"RD": | risk difference |
"HR": | log hazard ratio |
Note that informed prior distributions are only available for the effect size (\mu)
and heterogeneity (\tau) parameters. For effect moderation (prior_mods), the
informed effect prior is scaled by a factor of RoBMA.get_option("default_informed_priors.mods").
For heterogeneity moderation (prior_scale), a normal prior with standard deviation
specified by RoBMA.get_option("default_informed_priors.scale") is used.
Prior distributions can be fully customized by directly specifying the prior_effect,
prior_heterogeneity, prior_mods, prior_scale, and prior_heterogeneity_allocation
arguments. These should be prior distribution objects created via BayesTools::prior()
or related functions (e.g., prior_factor()).
The rescale_priors argument allows rescaling supported prior distributions by a
multiplicative factor. For example, rescale_priors = 2 doubles the standard
deviations/scales of normal, Cauchy, t, and inverse-gamma prior distributions,
making them more diffuse. Point and none priors are unchanged. For publication-bias
prior distributions, see publication_bias_prior_specification.
publication_bias_prior_specification,
prior, RoBMA.options,
brma
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.